@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_calcs.c 603 2004-04-16 09:58:26Z roms $ */
+/* $Id: tilp_calcs.c 804 2004-10-04 09:06:59Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -57,10 +57,12 @@ int tilp_calc_isready(void)
 	int err = 0;
 	TicalcType c = 0;
 	ticalc_get_calc(&c);
-	if (options.auto_detect
-	    && tifiles_is_flash(options.lp.calc_type) && (options.lp.
-							  calc_type !=
-							  CALC_V200)) {
+	if (options.auto_detect && 
+		tifiles_is_flash(options.lp.calc_type) && 
+		(options.lp.calc_type != CALC_TI84P) &&
+		(options.lp.calc_type != CALC_TI89T) &&
+		(options.lp.calc_type != CALC_V200)) 
+	{
 		err =
 		    ticalc_flash_isready((TicalcType *) &
 					 (options.lp.calc_type));
@@ -125,10 +127,12 @@ int tilp_calc_send_backup(char *filename)
 	case CALC_TI73:
 	case CALC_TI83:
 	case CALC_TI83P:
+	case CALC_TI84P:
 	case CALC_TI92:
 		gif->create_pbar_type3(_("Backup"));
 		break;
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92P:
 	case CALC_V200:
 		gif->create_pbar_type5(_("Backup"), "");
@@ -160,9 +164,11 @@ int tilp_calc_recv_backup(void)
 	case CALC_TI73:
 	case CALC_TI83:
 	case CALC_TI83P:
+	case CALC_TI84P:
 		gif->create_pbar_type3(_("Backup"));
 		break;
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92P:
 	case CALC_V200:
 		gif->create_pbar_type5(_("Backup"), "");
@@ -283,9 +289,18 @@ int tilp_calc_rom_dump(void)
 			return -1;
 		break;
 	case CALC_TI83P:
+	case CALC_TI84P:
+		ret = gif->msg_box4(_("Information"), _
+				    ("1: TiLP will automatically transfer the ROM dumping program\n2: but, it will wait for you to manually launch it from the calculator (either by the shell, either by typing 'Asm(DUMPROM)'.\nThanks to Benjamin Moody for the ROM dumper !"));
+		if (ret == BUTTON1)
+			return do_rom_dump(0);
+
+		else
+			return -1;
+		break;
 	case CALC_TI86:
 		ret = gif->msg_box4(_("Information"), _
-				    ("1: TiLP will automatically transfer the ROM dumping program\n2: but, it will wait for you to manually launch it from the calculator (either by the shell, either by typing 'asm(rom86)'."));
+				    ("1: TiLP will automatically transfer the ROM dumping program\n2: but, it will wait for you to manually launch it from the calculator (either by the shell, either by typing 'Asm(DUMPROM)'."));
 		if (ret == BUTTON1)
 			return do_rom_dump(0);
 
@@ -293,6 +308,7 @@ int tilp_calc_rom_dump(void)
 			return -1;
 		break;
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92P:
 	case CALC_V200:
 		return do_rom_dump(0);
@@ -350,11 +366,13 @@ int tilp_calc_send_flash_app(char *filename)
 	case CALC_TI82:
 	case CALC_TI83:
 	case CALC_TI83P:
+	case CALC_TI84P:
 	case CALC_TI85:
 	case CALC_TI92:
 		gif->create_pbar_type3(_("Flash"));
 		break;
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92P:
 	case CALC_V200:
 		gif->create_pbar_type3(_("Flash"));
@@ -415,7 +433,7 @@ int tilp_calc_send_flash_os(char *filename)
 		break;
 	}
 	old_timeout = ticable_get_timeout();
-	if(options.lp.calc_type == CALC_TI83P)
+	if((options.lp.calc_type == CALC_TI83P) || (options.lp.calc_type == CALC_TI84P))
 		ticable_set_timeout(300);
 	else
 		ticable_set_timeout(100);
@@ -443,7 +461,9 @@ int tilp_calc_recv_app(void)
 	switch (options.lp.calc_type) {
 	case CALC_TI73:
 	case CALC_TI83P:
+	case CALC_TI84P:
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92P:
 	case CALC_V200:
 		gif->create_pbar_type5(_("Receiving application(s)"), "");
@@ -539,7 +559,7 @@ int tilp_calc_ams2rom(char *filename)
 	info_update.start();
 
 	/* FLASH upgrade */
-	for (i = 0; i < ptr->data_length; i++) {
+	for (i = 0; i < (int)ptr->data_length; i++) {
 
 		//info_update.percentage = (float)i/ptr->data_length;
 		//info_update.pbar();
@@ -576,6 +596,7 @@ int tilp_calc_send_var(gint to_flash)
 			mode |= MODE_SEND_TO_FLASH;
 
 		else if (options.lp.calc_type == CALC_TI89
+			 || options.lp.calc_type == CALC_TI89T
 			 || options.lp.calc_type == CALC_TI92P
 			 || options.lp.calc_type == CALC_V200)
 			mode |= MODE_BACKUP;
@@ -679,8 +700,10 @@ int tilp_calc_recv_var(void)
 	case CALC_TI73:
 	case CALC_TI83:
 	case CALC_TI83P:
+	case CALC_TI84P:
 	case CALC_TI86:
 	case CALC_TI89:
+	case CALC_TI89T:
 	case CALC_TI92:
 	case CALC_TI92P:
 	case CALC_V200:
