@@ -1,5 +1,5 @@
 //* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_error.c 529 2004-04-08 14:29:07Z roms $ */
+/* $Id: tilp_error.c 735 2004-05-29 08:56:10Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -42,7 +42,7 @@ static GList *stack = NULL;
  */
 int tilp_error(int errcode)
 {
-	char s[256] = "code not found. This is a bug. Please report it.\n";
+	char s[512] = "code not found. This is a bug. Please report it.\n";
 #ifndef __MACOSX__
 	char *utf;
 	gsize bw;
@@ -59,7 +59,7 @@ int tilp_error(int errcode)
 	/* Pop error messages */
 	if (working_mode & MODE_GUI) {
 		int i;
-		for (i = 0; i < g_list_length(stack); i++) {
+		for (i = 0; i < (int)g_list_length(stack); i++) {
 			int err =
 			    GPOINTER_TO_INT((g_list_nth(stack, i))->data);
 
