@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tilp_files.c 529 2004-04-08 14:29:07Z roms $ */
+/* $Id: tilp_files.c 776 2004-07-02 20:37:37Z roms $ */
 
 /*  tilp - Ti Linking Program
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -43,6 +43,10 @@
 # include <grp.h>
 #endif				/* __WIN32__ */
 
+#ifdef __WIN32__
+#include "dirent.h"	// S_ISDIR
+#endif
+
 #include "tilp_core.h"
 //#include "dboxes.h"
 
@@ -143,7 +147,7 @@ int tilp_file_mkdir(const char *pathname)
 #else				/*  */
 int tilp_file_mkdir(const char *pathname)
 {
-	mkdir(pathname, MAXCHARS);
+	_mkdir(pathname);
 	return 0;
 }
 #endif				/*  */
@@ -303,8 +307,10 @@ const char *tilp_file_get_size(TilpFileInfo * fi)
 const char *tilp_file_get_type(TilpFileInfo * fi)
 {
 	static char buffer[32];
-	if (!strcmp(fi->name, ".."))
-		return "";
+
+    if (S_ISDIR(fi->attrib))
+        return "";
+
 	strncpy(buffer, tifiles_file_descriptive(fi->name), 32);
 	return buffer;
 }
@@ -352,8 +358,8 @@ int tilp_dirlist_local(void)
 	if (!stat(fi->name, &f_info)) {
 		fi->date = f_info.st_mtime;
 		fi->size = f_info.st_size;
-		fi->user = f_info.st_uid;
-		fi->group = f_info.st_gid;
+		//fi->user = f_info.st_uid;
+		//fi->group = f_info.st_gid;
 		fi->attrib = f_info.st_mode;
 	}
 
@@ -368,8 +374,8 @@ int tilp_dirlist_local(void)
 		if (!stat(fi->name, &f_info)) {
 			fi->date = f_info.st_mtime;
 			fi->size = f_info.st_size;
-			fi->user = f_info.st_uid;
-			fi->group = f_info.st_gid;
+			//fi->user = f_info.st_uid;
+			//fi->group = f_info.st_gid;
 			fi->attrib = f_info.st_mode;
 		}
 		//process_filename(fi->name);
@@ -541,6 +547,7 @@ void tilp_sort_files_by_size2(void)
 	}
 }
 
+#if 0
 void tilp_sort_files_by_user(void)
 {
 	GList *list = clist_win.dirlist;
@@ -618,6 +625,7 @@ void tilp_sort_files_by_group(void)
 		}
 	}
 }
+#endif
 
 void tilp_sort_files_by_attrib(void)
 {
@@ -812,8 +820,8 @@ char *tilp_file_underscorize(char *s)
 {
 	int i, j;
 	char tokens[] = "/\\:*?\"<>|- ";
-	for (i = 0; i < strlen(s); i++) {
-		for (j = 0; j < strlen(tokens); j++) {
+	for (i = 0; i < (int)strlen(s); i++) {
+		for (j = 0; j < (int)strlen(tokens); j++) {
 			if (s[i] == tokens[j])
 				s[i] = '_';
 		}
